pub struct IdeMenu { /* private fields */ }Expand description
Menu to present suggestions like similar to Ide completion menus
Implementations
Sourceimpl IdeMenu
impl IdeMenu
Sourcepub fn with_min_completion_width(self, width: u16) -> Self
pub fn with_min_completion_width(self, width: u16) -> Self
Menu builder with new value for min completion width
Sourcepub fn with_max_completion_width(self, width: u16) -> Self
pub fn with_max_completion_width(self, width: u16) -> Self
Menu builder with new value for max completion width
Sourcepub fn with_max_completion_height(self, height: u16) -> Self
pub fn with_max_completion_height(self, height: u16) -> Self
Menu builder with new value for max completion height
Sourcepub fn with_padding(self, padding: u16) -> Self
pub fn with_padding(self, padding: u16) -> Self
Menu builder with new value for padding
Sourcepub fn with_default_border(self) -> Self
pub fn with_default_border(self) -> Self
Menu builder with the default border
Sourcepub fn with_border(
self,
top_right: char,
top_left: char,
bottom_right: char,
bottom_left: char,
horizontal: char,
vertical: char,
) -> Self
pub fn with_border( self, top_right: char, top_left: char, bottom_right: char, bottom_left: char, horizontal: char, vertical: char, ) -> Self
Menu builder with new value for border
Sourcepub fn with_cursor_offset(self, cursor_offset: i16) -> Self
pub fn with_cursor_offset(self, cursor_offset: i16) -> Self
Menu builder with new value for cursor offset
Sourcepub fn with_description_mode(self, description_mode: DescriptionMode) -> Self
pub fn with_description_mode(self, description_mode: DescriptionMode) -> Self
Menu builder with new description mode
Sourcepub fn with_min_description_width(self, min_description_width: u16) -> Self
pub fn with_min_description_width(self, min_description_width: u16) -> Self
Menu builder with new min description width
Sourcepub fn with_max_description_width(self, max_description_width: u16) -> Self
pub fn with_max_description_width(self, max_description_width: u16) -> Self
Menu builder with new max description width
Sourcepub fn with_max_description_height(self, max_description_height: u16) -> Self
pub fn with_max_description_height(self, max_description_height: u16) -> Self
Menu builder with new max description height
Sourcepub fn with_description_offset(self, description_offset: u16) -> Self
pub fn with_description_offset(self, description_offset: u16) -> Self
Menu builder with new description offset
Sourcepub fn with_correct_cursor_pos(self, correct_cursor_pos: bool) -> Self
pub fn with_correct_cursor_pos(self, correct_cursor_pos: bool) -> Self
Menu builder with new correct cursor pos