pub struct Painter { /* private fields */ }Expand description
Implementation of the output to the terminal
Implementations
Sourceimpl Painter
impl Painter
Sourcepub fn screen_height(&self) -> u16
pub fn screen_height(&self) -> u16
Height of the current terminal window
Sourcepub fn screen_width(&self) -> u16
pub fn screen_width(&self) -> u16
Width of the current terminal window
Sourcepub fn set_semantic_markers(
&mut self,
markers: Option<Box<dyn SemanticPromptMarkers>>,
)
pub fn set_semantic_markers( &mut self, markers: Option<Box<dyn SemanticPromptMarkers>>, )
Sets the semantic prompt markers for terminal integration (OSC 133/633)
Sourcepub fn semantic_markers(&self) -> Option<&dyn SemanticPromptMarkers>
pub fn semantic_markers(&self) -> Option<&dyn SemanticPromptMarkers>
Returns a reference to the semantic prompt markers, if any
Sourcepub fn remaining_lines_real(&self) -> u16
pub fn remaining_lines_real(&self) -> u16
Returns the empty lines from the prompt down.
Sourcepub fn remaining_lines(&self) -> u16
pub fn remaining_lines(&self) -> u16
Returns the number of lines that are available or can be made available by stripping the prompt.
If you want the number of empty lines below the prompt,
use Painter::remaining_lines_real instead.
Sourcepub fn state_before_suspension(&self) -> PainterSuspendedState
pub fn state_before_suspension(&self) -> PainterSuspendedState
Returns the state necessary before suspending the painter (to run a host command event).
This state will be used to re-initialize the painter to re-use last prompt if possible.